@@ -21,7 +21,7 @@ from .exceptions import VeracodeAPIError
 from .applications import Applications, Sandboxes, CustomFields
 from .findings import Findings, SummaryReport
 from .policy import Policies
-from .sca import Workspaces
+from .sca import ComponentActivity, Workspaces
 from .collections import Collections
 from .identity import Users, Teams, BusinessUnits, APICredentials, Roles
 from .healthcheck import Healthcheck
@@ -188,6 +188,9 @@ class VeracodeAPI:
     def get_user_by_name(self,username):
         return Users().get_by_name(username)
 
+    def get_user_by_search(self, search_term=None, api_id=None, role_id=None, login_status=None, saml_user=None, team_id=None, detailed=False, user_type=None, request_params=None):
+        return Users().get_user_search(search_term,api_id,role_id,login_status,saml_user,team_id,detailed,user_type,request_params)
+
     def create_user (self,email,firstname,lastname,username=None,type="HUMAN",roles=[],teams=[],mfa=False):
         return Users().create(email,firstname,lastname,username,type,roles,teams,mfa=mfa)
 
@@ -325,6 +328,9 @@ class VeracodeAPI:
     def get_sca_scan(self,scan_id):
         return Workspaces().get_scan(scan_id)
 
+    def get_component_activity(self,component_id):
+        return ComponentActivity().get(component_id)
+
     #dynamic APIs
 
     def get_analyses(self):
