@@ -41,8 +41,10 @@ class XMLAPI():
         return APIHelper()._xml_request(self.baseurl + "/5.0/detailedreport.do", "GET", params={"build_id": build_id})
 
     def set_mitigation_info(self,build_id,flaw_id_list,action,comment):
-        """Adds a new mitigation proposal, acceptance, rejection, or comment for a set of flaws for an application."""
-        actiontype = Constants.ANNOT_TYPE.get(action, 'comment')        
+        """Adds a new mitigation proposal, acceptance, rejection, or comment for a set of flaws for an application.
+        Mitigation action types: ['appdesign','comment','fp','osenv','netenv','library','accepted','rejected','acceptrisk']
+        """
+        actiontype = Constants.ANNOT_TYPE.get(action, action)        
         payload = {'build_id': build_id, 'flaw_id_list': flaw_id_list, 'action': actiontype, 'comment': comment}
         return APIHelper()._xml_request(self.baseurl + "/updatemitigationinfo.do", "POST", params=payload)
 
@@ -55,4 +57,4 @@ class XMLAPI():
         else:
             payload = {'token': token}
 
-        return APIHelper()._xml_request(self.baseurl + "/3.0/downloadarcherreport.do", "GET", params=payload)
\ No newline at end of file
+        return APIHelper()._xml_request(self.baseurl + "/3.0/downloadarcherreport.do", "GET", params=payload)
